@@ -279,6 +279,7 @@ class BaseWriter:
             self.style_list.append(wtxf)
    
     def sheet(self,rdsheet,wtsheet_name):
+        
         # these checks should really be done by xlwt!
         if not wtsheet_name:
             raise ValueError('Empty sheet name will result in invalid Excel file!')
@@ -286,6 +287,11 @@ class BaseWriter:
         if l_wtsheet_name in self.wtsheet_names:
             raise ValueError('A sheet named %r has already been added!'%l_wtsheet_name)
         self.wtsheet_names.add(l_wtsheet_name)
+        l_wtsheet_name = len(wtsheet_name)
+        if len(wtsheet_name)>31:
+            raise ValueError('Sheet name cannot be more than 31 characters long, '
+                             'supplied name was %i characters long!'%l_wtsheet_name)
+        
         self.rdsheet = rdsheet
         self.wtsheet_name=wtsheet_name
         self.wtsheet = wtsheet = self.wtbook.add_sheet(wtsheet_name)
